#
# spec file for package roast
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           roast
Version:        9.0.0
Release:        1.1
Summary:        Simpler tar archiver and extractor
License:        MPL-2.0
URL:            https://github.com/openSUSE-Rust/roast
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
BuildRequires:  cargo
BuildRequires:  cargo-packaging
BuildRequires:  pkgconfig(libzstd)
BuildRequires:  pkgconfig(openssl)

%package -n obs-service-recomprizz
Summary:        OBS Source Service for recomprizz-ion
License:        MPL-2.0

%description -n obs-service-recomprizz
Utility to recompress to other compression formats.

%package -n obs-service-roast
Summary:        OBS Source Service for roast
License:        MPL-2.0

%description -n obs-service-roast
Utility to roast source directories into highly compressed tape archives.

%package -n obs-service-raw
Summary:        OBS Source Service for raw
License:        MPL-2.0

%description -n obs-service-raw
Utility to raw decompress tape archives to unarchived sources.

%package -n obs-service-roast_scm
Summary:        OBS Source Service for roast_scm
License:        MPL-2.0

%description -n obs-service-roast_scm
Utility to roast remote git repositories as tarball sources.

%package        fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and fish)
Requires:       %{name}
Requires:       fish
BuildArch:      noarch

%description    fish-completion
Fish command-line completion support for %{name}.

%package        zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and zsh)
Requires:       %{name}
Requires:       zsh
BuildArch:      noarch

%description    zsh-completion
Zsh command-line completion support for %{name}.

%package        bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and bash-completion)
Requires:       %{name}
Requires:       bash-completion
BuildArch:      noarch

%description    bash-completion
Bash command-line completion support for %{name}.

%description
Roast is a simple tar archiver and extractor with very high
compression settings for supported formats such as zstd.

It also supports recompression from an existing tarball.

%prep
%autosetup -a1

%build
%{cargo_build} -p roast-cli --bins -F obs --target-dir %{_builddir}/%{buildsubdir}/target
mkdir with_feature_obs/
cp %{_builddir}/%{buildsubdir}/target/release/roast with_feature_obs/
cp %{_builddir}/%{buildsubdir}/target/release/roast_scm with_feature_obs/
cp %{_builddir}/%{buildsubdir}/target/release/raw with_feature_obs/
cp %{_builddir}/%{buildsubdir}/target/release/recomprizz with_feature_obs/
# Build again for no obs feature. Those will be installed in %{_bindir}
%{cargo_build} -p roast-cli --bins --target-dir %{_builddir}/%{buildsubdir}/target

%install
mkdir -p %{buildroot}%{_prefix}/lib/obs/service
pushd roast-cli
%{cargo_install} --bins --target-dir %{_builddir}/%{buildsubdir}/target
popd
cp -v %{_builddir}/%{buildsubdir}/with_feature_obs/roast %{buildroot}%{_prefix}/lib/obs/service/roast
install -m0644 roast.service %{buildroot}%{_prefix}/lib/obs/service
cp -v %{_builddir}/%{buildsubdir}/with_feature_obs/recomprizz %{buildroot}%{_prefix}/lib/obs/service/recomprizz
install -m0644 recomprizz.service %{buildroot}%{_prefix}/lib/obs/service
cp -v %{_builddir}/%{buildsubdir}/with_feature_obs/raw %{buildroot}%{_prefix}/lib/obs/service/raw
install -m0644 raw.service %{buildroot}%{_prefix}/lib/obs/service
cp -v %{_builddir}/%{buildsubdir}/with_feature_obs/roast_scm %{buildroot}%{_prefix}/lib/obs/service/roast_scm
install -m0644 roast_scm.service %{buildroot}%{_prefix}/lib/obs/service

# Removes the Roast SCM binary with underscore name in /usr/bin
rm %{buildroot}/%{_bindir}/roast_scm

export PATH="${PATH:-}:%{buildroot}/%{_bindir}"
for roast_command in "roast-scm" "roast" "recomprizz" "raw"
do
  for shell in "zsh" "bash" "fish"
  do
    if [ "$shell" = "bash" ]
    then
          mkdir -p %{buildroot}%{_datadir}/bash-completion/completions/
    	$roast_command generate-completions-for "$shell" > %{buildroot}%{_datadir}/bash-completion/completions/${roast_command}.bash
    fi
    if [ "$shell" = "zsh" ]
    then
          mkdir -p %{buildroot}%{_datadir}/zsh/site-functions/
    	$roast_command generate-completions-for "$shell" > %{buildroot}%{_datadir}/zsh/site-functions/_${roast_command}
    fi
    if [ "$shell" = "fish" ]
    then
          mkdir -p %{buildroot}%{_datadir}/fish/vendor_completions.d/
    	$roast_command generate-completions-for "$shell" > %{buildroot}%{_datadir}/fish/vendor_completions.d/${roast_command}.fish
    fi
  done
done

%check
%{cargo_test} --test repro --target-dir %{_builddir}/%{buildsubdir}/target
%{cargo_test} --test shame --target-dir %{_builddir}/%{buildsubdir}/target

%files
%{_bindir}/roast
%{_bindir}/raw
%{_bindir}/recomprizz
%{_bindir}/roast-scm
%license LICENCE
%doc     CHANGELOG.md README.md

%files -n obs-service-roast
%dir %{_prefix}/lib/obs
%dir %{_prefix}/lib/obs/service
%{_prefix}/lib/obs/service/roast
%{_prefix}/lib/obs/service/roast.service
%license LICENCE
%doc     CHANGELOG.md README.md

%files -n obs-service-recomprizz
%dir %{_prefix}/lib/obs
%dir %{_prefix}/lib/obs/service
%{_prefix}/lib/obs/service/recomprizz
%{_prefix}/lib/obs/service/recomprizz.service
%license LICENCE
%doc     CHANGELOG.md README.md

%files -n obs-service-raw
%dir %{_prefix}/lib/obs
%dir %{_prefix}/lib/obs/service
%{_prefix}/lib/obs/service/raw
%{_prefix}/lib/obs/service/raw.service
%license LICENCE
%doc     CHANGELOG.md README.md

%files -n obs-service-roast_scm
%dir %{_prefix}/lib/obs
%dir %{_prefix}/lib/obs/service
%{_prefix}/lib/obs/service/roast_scm
%{_prefix}/lib/obs/service/roast_scm.service
%license LICENCE
%doc     CHANGELOG.md README.md

%files bash-completion
%dir %{_datadir}/bash-completion
%dir %{_datadir}/bash-completion/completions
%{_datadir}/bash-completion/completions/*

%files fish-completion
%dir %{_datadir}/fish
%dir %{_datadir}/fish/vendor_completions.d
%{_datadir}/fish/vendor_completions.d/*

%files zsh-completion
%dir %{_datadir}/zsh
%dir %{_datadir}/zsh/site-functions
%{_datadir}/zsh/site-functions/*

%changelog
* Sun Jun 22 2025 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 9.0.0:
  * chore(release): v9.0.0
  * dependencies: specify clap_complete version
  * feat: create a new binary name for `roast_scm`.
  * dependencies: remove `walkdir`
  * fix(tests): add missing fields
  * feat: add new subcommand `generate-completions-for` using `clap_complete`
  * dependencies: add clap_complete
  * workspace: update workspace default members
  * refactor: `copy_dir_all` should canonicalise the paths to original sources first.
* Thu Jun 19 2025 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 8.1.5:
  * chore(release): bump to v8.1.5
  * fix: just add one newline lol
* Thu Jun 19 2025 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 8.1.4:
  * chore(release): v8.1.4
  * fix: finally properly fix adding the newline.
  * chore(release): v8.1.3
  * fix: add newline at the end of the file properly
  * chore(release): bump to v8.1.2
  * tests: switch test case from deno to river
  * format: run `cargo +nightly fmt`
  * tests: add deno and jay, they're known to contain submodules
  * fix: update submodule logic if in case the submodule path does not exist.
* Thu Jun 19 2025 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 8.1.1:
  * chore(release): bump to v8.1.1
  * docs: renaming scheme is now "better"
  * docs: the `.changes` filename is based on the filename without the version part.
  * docs: clarify what the header is for
  * docs: fix grammar here
  * docs: update README
  * docs: fix README.md. `obs` feature flag only updates the version in the specfile.
* Sun Jun 15 2025 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 8.1.0:
  * chore(release): bump to v8.1.0
  * docs: update README.md to reflect new behaviour
  * ci: add a note for why tests are separated.
  * improvement: feature obs will just call `set_version_in_specfile`.
  * format: run `cargo +nightly fmt`
  * fix: more clap fix workarounds. `changesauthor` is required if `changesgenerate` is set to true.
  * fix: "prepend" -> "it prepends"
  * fix: word should be prepend and not append.
  * fix: `requires_if` to `required_if_eq`
  * docs: fix typos and inconsistencies in README.md
  * docs: update README
  * docs: update README.md
  * docs: update README.md
* Fri Jun 13 2025 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 8.0.0:
  * chore(release): bump to v8.0.0
  * refactor: `renamepattern` should require `rename`
  * docs: update recomprizz.service file to match new features
  * Merge branch '20250613-using-no-walkdir'
  * misc: make the warning clear if renaming fails because of wrong file extension
  * refactor: rework recomprizz renaming logic
  * refactor: rework recomprizz args fields to introduce renaming with regex.
  * ci: switch to leap image
  * improvement: remove any usage of walkdir
  * remove: removal of walkdir crate since we are using standard library's fs module only.
* Sun Jun  8 2025 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 7.2.4:
  * chore(release): bump to v7.2.4
  * dependencies: remove semver crate
  * misc: add newline to the end of the file if file was not empty before.
  * Revert "misc: add newline at the end of the dot changes file"
  * misc: add newline at the end of the dot changes file
  * refactor: improve getting "number of changes since" logic
  * misc: change short flag to U
  * misc: change short flag to U
* Fri Jun  6 2025 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 7.2.3+git3.gc75d73f8953641bc46255a40348edf4c4c0852c3:
  * refactor: improve getting "number of changes since" logic
  * misc: change short flag to U
  * misc: change short flag to U
* Tue Jun  3 2025 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 7.2.3:
  * chore(release): bump to version 7.2.3
  * fix: refactor so that after a deletion of tag does not cause an error
* Mon Jun  2 2025 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 7.2.0:
  * chore(release): bump to version 7.2.0
  * tests: roast_scm_opts should have `None` as the first parameter
  * improvement: add a possibility to pass a custom workdir
* Sun Jun  1 2025 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 7.1.2:
  * chore(release): bump to version 7.1.2
  * improvement: only update the changelog header if possible
  * ci: forgot to enable obs in the feature flag
* Sun Jun  1 2025 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 7.1.1:
  * chore(release): bump to v7.1.1
  * ci: forgot to specify which test to run
  * ci: include a test for feature `obs`
  * misc: update only once the version string.
  * tests: test feature `obs`
* Sat May 31 2025 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Ignore test for scm.
* Sat May 31 2025 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 7.1.0:
  * chore(release): bump to v7.1.0
  * fix: date format now fixed
  * chore(release): bump to v7.0.0
  * docs: update README
  * docs: update roast_scm.service file
  * format: run `cargo +nightly fmt`
  * fix: apply clippy suggestions
  * fix: disable `obs` feature for now in tests
  * tests: add tests for roast scm
  * add space
  * misc: cleanup and whether to disable or enable code for `obs` feature
  * docs: document the `obs` feature in Cargo.toml
  * docs: update wording
  * fix: change alias for changesemail
  * ci: seems it needs to be more specific where with this blob for *.rs
  * clippy: remove needless borrow
  * ci: test if CI runs with this config
  * refactor: put set_version logic inside `map` as well. create separate function for changelog file generation.
  * refactor: move changelog file generator code inside `map`
  * Merge branch '20250523-improve-scm'
  * fix: add the last newline
  * feat: append email if `changesemail` passed.
  * feat: add `changesemail` field for cli
  * cleanup
  * misc: add optional obs feature in roast-cli
  * feat: implement update version in specfile
  * feat: cli has new fields, `set_name` and `set_version` for obs feature
  * misc: add optional obs feature
  * misc: apply `trim()` first for strings before checking if they're empty
  * misc: `split('\n')` -> `lines()`
  * misc: use the `to_extension()` method
  * misc: change this to an iterator
  * refactor: use `any` since it returns at the first true, otherwise, false.
  * refactor: use iterators over for loops
  * misc: change wording
  * misc: cleanup code for feature, changelog generation.
  * feat: changelog generation is now implemented.
  * dependencies: add hifitime
  * misc: add initial logic for `changesgenerate` feature
  * feat: add new cli arguments and fieldnames for `RoastScmArgs` related to `changesgenerate`
  * fix: `remote_checkout_branch` creating a branch from remote branch with incorrect name
  * api: cleanup visibility and privacy of certain functions
  * misc: more cleanup
  * begin iterating for a new future version
  * misc: add cliff.toml for changelog generation config
  * fixes: the refactor caused the commit hash to be skipped
  * docs: add where the final filename is based on.
  * format: run `cargo +nightly fmt`
  * improvements: replace dumb lookup by reading config instead
  * fix: `versionrewriteregex` should require `versionrewritepattern`
  * feat: `versionrewriteregex` and `versionrewritepattern` implemented
  * dependencies: add regex crate
  * fix: it should be prefixed with `g`
  * fix: version format improvements and fixes
  * feat: initial versionformat prefix
  * fixes: checkout should not error if branch is HEAD. sorting in revwalk should not be reversed.
  * refactor: more cleanup. remove redundant logic
  * misc: cleanup code
  * misc: make it clear what depth was set in the warnings
  * performance: do a dumb revision lookup to check if a revision is a branch
  * fix: use set_head_detached since we want it to point to a commit
  * fix: add condition if branch ref is the current HEAD
  * improvements: if there is no changelog, warn the user
  * format: run `cargo +nightly fmt`
  * improvements: roast_scm now is able to generate some changelog
  * roast_scm: generate changelog improvements
  * common: add `to_extension` method for Compression
  * improvements: describe string is implemented alongside improved log messages
  * fix: set this to 0
  * clippy: remove redundant &
  * roast_scm: initial refactor of the cloning process and finding the revision
  * dependencies: add semver
  * docs: update README
  * fmt: run \`cargo +nightly fmt\`
* Mon May 19 2025 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 6.1.1:
  * improvements: allow returning an `Option<PathBuf>` if is-temporary is set to `false`.
  * fix: import correctly `std::path::PathBuf`.
  * fix: use the correct return type inside the map.
  * fix: ensure that the outdir exists
  * docs: this is roast_scm. this file was copied from recomprizz so it was overlooked accidentally
  * docs: fix typo in README.md
  * fix: return type should be Result<Option<PathBuf>>
  * fix: return type should be Result<Option<PathBuf>>
  * fix: return Ok(())
* Sat May 17 2025 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 6.1.0. This includes changes that are from 6.0.0.
  * clippy: apply clippy fixes
  * docs: add and improve doc comments
  * chore: version bump dependencies
  * fix: it should be evaluated if it's false
  * fix: add let binding
  * improvements: feature is-temporary now have clearer messages if directory was not deleted.
  * cli: set the is-temporary with ArgAction::Set
  * docs: improvements on how everything works
  * feat: is-temporary flag now used.
  * docs: add roast_scm.service
  * format: run `cargo +nightly fmt`
  * clippy: apply clippy fixes
  * fix: remove unused key in roast-cli's Cargo.toml
* Wed Nov 27 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 5.1.7:
  * feat: add zstd as another alias for zst
  * prepare structure for roast-scm
  * minor: improve error message here
  * fix: added trace feature
* Sat Nov  2 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 5.1.6:
  * fix: revert 8977c6741364c6d25fb33408d8b4232d835a768b
* Sat Nov  2 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 5.1.5:
  * add service files. they serve as documentation
  * fix mismatched types in roast-cli
  * Bump zstd and infer
  * clippy: rectify the needless pass by value
  * chore: set resolver to 2 and enforce strict linting rules
  * fix: just use an empty "" if strip fails
  * add COC and CONTRIBUTING
  * cleanup deps and begin cycle
  * remove comment for 037aa62
  * docs: removed warning. ensured reproducibility.
* Fri Nov  1 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 5.1.2:
  * minor: improvements on how we sort files and directories
  * use rayon while you can
  * performance: add rayon to parallelise copying operations
  * docs: add important difference between ADDED and INCLUDED [ci skip]
  * docs: improve wording [ci skip]
  * docs: fix grammar [ci skip]
  * docs: explain how the path behaviour works
  * refactor: improve the logic handling for adding, excluding and including
  * improve message logs
  * fix: resolved some edge-cases with additional paths and included paths
  * fix: reimplement adding of archive files
  * doc: update README on CLI help
  * feat and fix: properly implement exclude and include
  * cli: finalise flags. begin cycle
  * major: begin refactor cycle [ci skip]
  * logging: set to trace level for filter_paths
  * fix: avoid duplicating entries
  * fix: do not consider temporary directory as hidden
  * fix: just use ends_with to check if it's a valid file extension
  * improvement: also filter_paths for each element in additional_paths
  * feat: hidden file and gitignore finally correctly implemented
- New subpackage: obs-service-roast
* Sun Oct 20 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 4.5.0:
  * docs: update README and include instructions regarding renaming
  * minor: update tests and update paths code
  * feat: add glob support
  * fix: actually implement the fix for ef1e6f857e48821198d720d092bc7087af762f2a
  * feat: add glob support to all
* Sun Oct 20 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 4.2.0:
  * fix: filename should leave out version part alone
* Sun Oct 20 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 4.1.0:
  * lib: move over copy_dir_all as a common utility
  * cli: move logic as cli stubs
  * tests: use copy_dir_all as part of lib now instead
  * roast and raw: improve description of cli options then format
  * move raw and roast modules to standalone files
  * cli: add recomprizz args
  * recomprizz: initial implementation
  * import termcap
  * fix: apply clippy lints
  * tracing: set logic where and when to start properly
  * apply clippy lints + format
  * set output path correctly
  * refactor: canonicalize filter
  * refactor: canonicalize paths
  * update deps
  * reproducibility: set to false by default
  * fix: additional paths variable should only be a collection of files and not directories
  * doc: add a warning regarding reproducibility
  * doc: fix warning msg
  * doc: fix warning msg
  * refactor: move mostly to libroast
  * refactor: improve field naming and description
  * refactor: remove tracing crate unused imports
  * minor: raaaaaaaaaaaaawwwwwwww
  * make names consistent
  * remove: cliff.toml and git-cliff is an overengineered changelog generator
  * prepare justfile for publishing
  * change it to a text file
  * cli: allow to explicitly tell "true" or "false" using ArgAction::Set and add our service file
- Add new subpackage `obs-service-recomprizz`
  * This is a possible drop-in replacement for obs-service-recompress
* Sat Oct 19 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 3.3.1:
  * tests: add library tests + ci tests
  * test: this should be two separate files
* Tue Oct 15 2024 Soc Virnyl Estela <obs@uncomfyhalomacro.pl>
- Update to version 3.3.0:
  * Properly set preserve root
  * Cleanup raw binary log output
  * Support uncompressed tarballs with tar extension
* Sat Oct 12 2024 Soc Virnyl Estela <obs@uncomfyhalomacro.pl>
- Initial spec for roast 3.2.2
